#include "RUtils.h"
#include "RSGGobi.h"

int R_IS(USER_OBJECT_ obj, const char * const name)
{
 int i, n;
 USER_OBJECT_ className;
 
 className = getAttrib(obj, R_ClassSymbol);
 n = GET_LENGTH(className);

  for(i=0;i<n;i++) {
    if(strcmp(name, CHAR(STRING_ELT(className, i))) == 0) {
#if LDEBUG      
printf("Is a %s\n", name);
PrintValue(obj);
#endif
       return(TRUE);
     }
  }
 return(FALSE); 
}  


SEXP
isSameRef(USER_OBJECT_ x, USER_OBJECT_ y)
{
   SEXP ans;
   void *a, *b;
   
   ans = NEW_LOGICAL(1);
   a = R_ExternalPtrAddr(x);
   b = R_ExternalPtrAddr(y);
   INTEGER_DATA(ans)[0] = (a == b);
   return(ans);
}


void
RS_throwError(char *msg)
{
  PROBLEM msg
  ERROR;
}
